#!/usr/bin/env bash

if [ -d "${PWD}/deploy" ]; then
  SCRIPT_DIR="${PWD}/deploy"
else
  SCRIPT_DIR="${PWD}"
fi

: "${PORT:=8880}"
: "${CONTROL_PORT:=8881}"

if [[ "${K8S_POD}" =~ "-vlc-" ]]; then
  SQS_QUEUE_URI=${SQS_QUEUE_VLC_URI}
fi

# compare with helm values
if [[ "${SVC_SUPERARTIFACT_ASSET_CACHE_INCARNATION}" == "aws" ]]; then
  INCARNATION=workerAws
elif [[ "${SVC_SUPERARTIFACT_ASSET_CACHE_INCARNATION}" == "azure" ]]; then
  INCARNATION=workerAzure
elif [[ "${SVC_SUPERARTIFACT_ASSET_CACHE_INCARNATION}" == "alicloud" ]]; then
  INCARNATION=workerAlicloud
elif [[ "${SVC_SUPERARTIFACT_ASSET_CACHE_INCARNATION}" == "gcp" ]]; then
  INCARNATION=workerGcp
else
  INCARNATION=default
fi
echo "service incarnation=$INCARNATION"
echo "SQS env:"
env | grep SQS

echo "JAVA_MEMORY_ARGS=$JAVA_MEMORY_ARGS"

echo "JAVA_OPTS=$JAVA_OPTS"

echo "JAVA_HEAP_MIN=$JAVA_HEAP_MIN"
echo "JAVA_HEAP_MAX=$JAVA_HEAP_MAX"

echo "Print all HOST env vars"
env | grep HOST

# https://spark.apache.org/docs/latest/tuning.html#garbage-collection-tuning
# consider -XX:+UseG1GC which may need -XX:G1HeapRegionSize, and also try -XX:+UseStringDeduplication
export JAVA_GC_OPTS="-verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps" # -XX:+PrintGCCause
# enable insecure JMX access to allow jconsole to connect to POD using port-forward; usee 8199 instead of 1099
export JMX_OPTS="-Dcom.sun.management.jmxremote=true -Dcom.sun.management.jmxremote.port=8199 -Dcom.sun.management.jmxremote.rmi.port=8199 -Dcom.sun.management.jmxremote.local.only=false -Dcom.sun.management.jmxremote.authenticate=false -Dcom.sun.management.jmxremote.ssl=false -Djava.rmi.server.hostname=127.0.0.1"
# unclear if we also need -XX:OnOutOfMemoryError="kill -9 %p"
export JAVA_OOM_OPTS=$JAVA_OOM_OPTS

status=0
set +e
TZ=UTC java $JAVA_OPTS $JAVA_MEMORY_ARGS -Xmx$JAVA_HEAP_MAX -Xms$JAVA_HEAP_MIN $JAVA_GC_OPTS $JMX_OPTS $JAVA_OOM_OPTS -XshowSettings:vm -jar "${SCRIPT_DIR}/asset-cache.jar" $INCARNATION -server.port=:$PORT -management.server.port=:$CONTROL_PORT $*
status=$?
set -e

echo "$(date): jvm exited with status code ${status}"
exit ${status}
